==> speech-analytic-testing_3.6.0_database.tar.gz: database/mssql/procedures/GetProcessInteractionsByProcessId.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[GetProcessInteractionsByProcessId] (
	@VCC		VARCHAR(50) = NULL,
	@ProcessId	VARCHAR(50) = NULL,
	@ResultType VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- ESTA FUNCION RETORNA LAS INTERACCIONES DE TEXTO Y AUDIO RELACIONADA A UN PROCESS

	IF @ResultType = 'RAW' 
	BEGIN
		-- RESULTADO TIPO RAW GENERA UN RESULTADO CON LOS DATOS Y NOMBRES DE COLUMNAS COMO VIENEN DE HD

		SELECT CONCAT(A.[ID], '_', A.[Section], '_', A.[PArt])				'ID',
				A.[ID]														'InteractionId',
				A.[Section]													'Section',
				A.[Part]													'Part',
				'CALL'														'Channel',
				A.[Number]													'Number',
				A.[Gender]													'Gender',
				A.[SilenceTime]												'Silence',
				A.[DurationTime]											'DurationTime',
				A.[DurationTime]											'AtentionTime',
				A.[Category1]												'Category1',
				A.[Category2]												'Category2',
				A.[Category3]												'Category3',
				A.[Description]												'Description',
				A.[DispositionCode]											'DispositionCode',
				A.[Campaign]												'Campaign',
				A.[Agent]													'Agent',
				A.[Number]													'contactName',
				A.[Type]													'Type',
				A.[StartDate]												'StartDate',
				A.[EndDate]													'EndDate',
				NULL														'Format',
				A.[ValidChar]												'validChar',
				A.[TotalPhrases]											'totalPhrases',

				A.[ContactAddress]											'contactAddress'
			FROM [dbo].[ProcessAudio] PA (NOLOCK)
			INNER JOIN [dbo].[Audio] A (NOLOCK)
				ON A.[VCC] = PA.[VCC]
					AND A.[ID] = PA.[AudioId]
					AND A.[Section] = PA.[Section]
					AND A.[Part] = PA.[Part]
			WHERE PA.[VCC] = @VCC
				AND PA.[ProcessId] = @ProcessId
				

		SELECT PAI.[VCC]								'vcc', 
				PAI.[InteractionId]						'id', 
				PAI.[FormattedEndDate]					'folder',
				AI.[ExportedContent]					'exportedContent',
				PAI.[InteractionType]					'channel',
				PAI.[Campaign]							'campaign',
				AI.[StartDate]							'startDate',
				AI.[EndDate]							'endDate',
				AI.[Account]							'account',
				AI.[Initiative]							'initiative',
				AI.[ContactName]						'contactName',
				AI.[FirstTakedAgent]					'firstTakedAgent',
				AI.[LastTakedAgent]						'lastTakedAgent', 
				AI.[IsTaken]							'isTaken',
				AI.[TotalMessages]						'totalMessages',
				AI.[DurationTime]						'durationTime',
				AI.[AttentionTime]						'attentionTime',
				AI.[DispositionCode]					'dispositionCode',
				AI.[DispositionTreePath]				'dispositionTreePath',
				CASE WHEN AI.[TotalPhrases] IS NULL 
					THEN AI.[RawChar] ELSE 0 END		'rawChar',
				ISNULL(AI.[TotalPhrases], 0)			'totalPhrases',
				AI.ContactAddress						'contactAddress'
			FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
			INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON AI.[VCC] = PAI.[VCC]
					AND AI.[ID] = PAI.[InteractionId]
					AND AI.[Channel] = PAI.[InteractionType]
					AND AI.[Folder] = PAI.[FormattedEndDate]
			WHERE PAI.[VCC] = @VCC
				AND PAI.[ProcessId] = @ProcessId
				
	END

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetProcessInteractionsByProcessId.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
 CREATE PROCEDURE [dbo].[GetProcessInteractionsByProcessId]
(
	@VCC		VARCHAR(50) = NULL,
	@ProcessId	VARCHAR(50) = NULL,
	@ResultType VARCHAR(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- ESTA FUNCION RETORNA LAS INTERACCIONES DE TEXTO Y AUDIO RELACIONADA A UN PROCESS

	IF @ResultType = 'RAW' 
	BEGIN
		-- RESULTADO TIPO RAW GENERA UN RESULTADO CON LOS DATOS Y NOMBRES DE COLUMNAS COMO VIENEN DE HD

		SELECT CONCAT(A.[ID], '_', A.[Section], '_', A.[PArt])				'ID',
				A.[ID]														'InteractionId',
				A.[Section]													'Section',
				A.[Part]													'Part',
				'CALL'														'Channel',
				A.[Number]													'Number',
				A.[Gender]													'Gender',
				A.[SilenceTime]												'Silence',
				A.[DurationTime]											'DurationTime',
				A.[DurationTime]											'AtentionTime',
				A.[Category1]												'Category1',
				A.[Category2]												'Category2',
				A.[Category3]												'Category3',
				A.[Description]												'Description',
				A.[DispositionCode]											'DispositionCode',
				A.[Campaign]												'Campaign',
				A.[Agent]													'Agent',
				A.[Number]													'contactName',
				A.[Type]													'Type',
				A.[StartDate]												'StartDate',
				A.[EndDate]													'EndDate',
				NULL														'Format',
				A.[ValidChar]												'validChar',
				A.[TotalPhrases]											'totalPhrases',
				A.[ContactAddress]											'contactAddress',
				A.[NeedI6Update]											'needI6Update'
			FROM [dbo].[ProcessAudio] PA (NOLOCK)
			INNER JOIN [dbo].[Audio] A (NOLOCK)
				ON A.[VCC] = PA.[VCC]
					AND A.[ID] = PA.[AudioId]
					AND A.[Section] = PA.[Section]
					AND A.[Part] = PA.[Part]
			WHERE PA.[VCC] = @VCC
				AND PA.[ProcessId] = @ProcessId
				

		SELECT PAI.[VCC]													'vcc', 
				PAI.[InteractionId]											'id', 
				PAI.[FormattedEndDate]										'folder',
				AI.[ExportedContent]										'exportedContent',
				PAI.[InteractionType]										'channel',
				PAI.[Campaign]												'campaign',
				AI.[StartDate]												'startDate',
				AI.[EndDate]												'endDate',
				AI.[Account]												'account',
				AI.[Initiative]												'initiative',
				AI.[ContactName]											'contactName',
				AI.[ContactAddress]											'contactAddress',
				AI.[FirstTakedAgent]										'firstTakedAgent',
				AI.[LastTakedAgent]											'lastTakedAgent', 
				AI.[IsTaken]												'isTaken',
				AI.[TotalMessages]											'totalMessages',
				AI.[DurationTime]											'durationTime',
				AI.[AttentionTime]											'attentionTime',
				AI.[DispositionCode]										'dispositionCode',
				AI.[DispositionTreePath]									'dispositionTreePath',
				CASE WHEN AI.[TotalPhrases] IS NULL 
					THEN AI.[RawChar] ELSE 0 END							'rawChar',
				ISNULL(AI.[TotalPhrases], 0)								'totalPhrases',
				AI.[NeedI6Update]											'needI6Update'
			FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
			INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON AI.[VCC] = PAI.[VCC]
					AND AI.[ID] = PAI.[InteractionId]
					AND AI.[Channel] = PAI.[InteractionType]
					AND AI.[Folder] = PAI.[FormattedEndDate]
			WHERE PAI.[VCC] = @VCC
				AND PAI.[ProcessId] = @ProcessId
				
	END

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
